==> agr-center-infrastructure-3.0.0-CLOUD-20221226.112038-2-sources.jar: com/tydic/dyc/agr/repository/po/AgrMainPO.java <==
package com.tydic.dyc.agr.repository.po;

import lombok.Data;
import java.io.Serializable;
import java.util.Date;
import java.util.List;

/**
 * 描述：agr_main
 * 
 * @author auto_gen
 * @date 2022-10-24 16:03
 **/
@Data
public class AgrMainPO implements Serializable {
	private static final long serialVersionUID =  -1844341747723334414L;

	/**
	 * 协议ID
	 */
	private Long agrId;
	/**
	 * 协议编号
	 */
	private String agrCode;
	/**
	 * 协议版本
	 */
	private String agrVersion;
	/**
	 * 外部关联编号
	 */
	private String relCode;
	/**
	 * 企业协议编号
	 */
	private String enAgrCode;
	/**
	 * 租户ID
	 */
	private String tenantId;
	/**
	 * 父协议ID
	 */
	private Long parentAgrId;
	/**
	 * 协议名称
	 */
	private String agrName;
	/**
	 * 协议模式
	 */
	private Integer agrMode;
	/**
	 * 协议分类
	 */
	private Integer agrType;
	/**
	 * 协议状态
	 */
	private Integer agrStatus;
	/**
	 * 协议价格类型
	 */
	private Integer agrPriceType;
	/**
	 * 协议类别名称
	 */
	private String agrCategoryName;
	/**
	 * 协议类别id
	 */
	private Long agrCategoryId;
	/**
	 * 协议来源
	 */
	private Integer agrSrc;
	/**
	 * 协议来源名称
	 */
	private String agrSrcName;
	/**
	 * 协议来源编码
	 */
	private String agrSrcCode;
	/**
	 * 交易模式
	 */
	private Integer tradeMode;
	/**
	 * 铺货方式
	 */
	private Integer vendorMode;
	/**
	 * 是否配送
	 */
	private Integer whetherDispatch;
	/**
	 * 是否分配
	 */
	private Integer whetherAssign;
	/**
	 * 协议生效日期
	 */
	private Date effDate;
	private Date effDateStart;
	private Date effDateEnd;
	/**
	 * 协议失效日期
	 */
	private Date expDate;
	private Date expDateStart;
	private Date expDateEnd;
	/**
	 * 标的物名称
	 */
	private String matterName;
	/**
	 * 管理单位ID
	 */
	private Long managementOrgId;
	/**
	 * 管理单位名称
	 */
	private String managementOrgName;
	/**
	 * 采购单位ID
	 */
	private Long purchaseOrgId;
	/**
	 * 采购单位名称
	 */
	private String purchaseOrgName;
	/**
	 * 供货商ID
	 */
	private Long supplierId;
	/**
	 * 供货商名称
	 */
	private String supplierName;
	/**
	 * 供货商联系人
	 */
	private String supplierContact;
	/**
	 * 供货商联系电话
	 */
	private String supplierPhone;
	/**
	 * 结算单位ID
	 */
	private Long settlementOrgId;
	/**
	 * 结算单位名称
	 */
	private String settlementOrgName;
	/**
	 * 采购类别
	 */
	private Integer agreementVariety;
	/**
	 * 供货周期
	 */
	private Integer supplyCycle;
	/**
	 * 质保期单位
	 */
	private String quaprotectUnit;
	/**
	 * 质保期时间
	 */
	private String quaprotectCount;
	/**
	 * 质保期(月)
	 */
	private Integer warantty;
	/**
	 * 所属专区
	 */
	private Integer agrLocation;
	/**
	 * 是否商城铺货标识
	 */
	private Integer whetherStorePlan;
	/**
	 * 应用范围类型
	 */
	private Integer scopeType;
	/**
	 * 调价机制
	 */
	private Integer adjustPrice;
	/**
	 * 组织名称
	 */
	private String agrOrgName;
	/**
	 * 其他付款条件
	 */
	private String payCase;
	/**
	 * 协议签订时间
	 */
	private Date agrSignTime;
	private Date agrSignTimeStart;
	private Date agrSignTimeEnd;
	/**
	 * 经办人ID
	 */
	private Long agrOperatorId;
	/**
	 * 经办人名称
	 */
	private String agrOperatorName;
	/**
	 * 经办人用户名
	 */
	private String agrOperatorUsername;
	/**
	 * 编制人名称
	 */
	private String createName;
	/**
	 * 编制人用户名
	 */
	private String createUsername;
	/**
	 * 编制人ID
	 */
	private Long createLoginId;
	/**
	 * 编制时间
	 */
	private Date createTime;
	private Date createTimeStart;
	private Date createTimeEnd;
	/**
	 * 编制人单位
	 */
	private Long createOrgId;
	/**
	 * 编制人单位名称
	 */
	private String createOrgName;
	/**
	 * 更新者ID
	 */
	private Long updateLoginId;
	/**
	 * 更新人
	 */
	private String updateName;
	/**
	 * 更新人用户名
	 */
	private String updateUsername;
	/**
	 * 删除标志
	 */
	private Integer delTag;
	/**
	 * 更新时间
	 */
	private Date updateTime;
	private Date updateTimeStart;
	private Date updateTimeEnd;
	/**
	 * 备注
	 */
	private String remark;
	/**
	 * 协议ID集合
	 */
	private List<Long> agrIds;
	/**
	 * 机构树路径
	 */
	private String orgPath;
	/**
	 * 确认时间
	 */
	private Date confirmTime;
	private Date confirmTimeStart;
	private Date confirmTimeEnd;
	/**
	 * 确认人
	 */
	private String confirmName;
	/**
	 * 排序
	 */
	private String orderBy;

}

==> agr-center-infrastructure-3.1.1.0-CLOUD-20230307.061844-4-sources.jar: com/tydic/dyc/agr/repository/po/AgrMainPO.java <==
package com.tydic.dyc.agr.repository.po;

import lombok.Data;
import java.io.Serializable;
import java.util.Date;
import java.util.List;

/**
 * 描述：agr_main
 * 
 * @author auto_gen
 * @date 2023-02-08 12:04
 **/
@Data
public class AgrMainPO implements Serializable {
	private static final long serialVersionUID =  8352730266166234744L;

	/**
	 * 协议ID
	 */
	private Long agrId;
	/**
	 * 协议编号
	 */
	private String agrCode;
	/**
	 * 协议版本
	 */
	private String agrVersion;
	/**
	 * 外部关联编号
	 */
	private String relCode;
	/**
	 * 企业协议编号
	 */
	private String enAgrCode;
	/**
	 * 租户ID
	 */
	private String tenantId;
	/**
	 * 父协议ID
	 */
	private Long parentAgrId;
	/**
	 * 协议名称
	 */
	private String agrName;
	/**
	 * 协议模式
	 */
	private Integer agrMode;
	/**
	 * 协议分类
	 */
	private Integer agrType;
	/**
	 * 协议状态
	 */
	private Integer agrStatus;
	/**
	 * 协议价格类型
	 */
	private Integer agrPriceType;
	/**
	 * 协议类别名称
	 */
	private String agrCategoryName;
	/**
	 * 协议类别id
	 */
	private Long agrCategoryId;
	/**
	 * 协议来源
	 */
	private Integer agrSrc;
	/**
	 * 协议来源名称
	 */
	private String agrSrcName;
	/**
	 * 协议来源编码
	 */
	private String agrSrcCode;
	/**
	 * 交易模式
	 */
	private Integer tradeMode;
	/**
	 * 铺货方式
	 */
	private Integer vendorMode;
	/**
	 * 是否配送
	 */
	private Integer whetherDispatch;
	/**
	 * 是否分配
	 */
	private Integer whetherAssign;
	/**
	 * 协议生效日期
	 */
	private Date effDate;
	private Date effDateStart;
	private Date effDateEnd;
	/**
	 * 协议失效日期
	 */
	private Date expDate;
	private Date expDateStart;
	private Date expDateEnd;
	/**
	 * 标的物名称
	 */
	private String matterName;
	/**
	 * 管理单位ID
	 */
	private Long managementOrgId;
	/**
	 * 管理单位名称
	 */
	private String managementOrgName;
	/**
	 * 采购单位ID
	 */
	private Long purchaseOrgId;
	/**
	 * 采购单位名称
	 */
	private String purchaseOrgName;
	/**
	 * 供货商ID
	 */
	private Long supplierId;
	/**
	 * 供货商名称
	 */
	private String supplierName;
	/**
	 * 供货商联系人
	 */
	private String supplierContact;
	/**
	 * 供货商联系电话
	 */
	private String supplierPhone;
	/**
	 * 结算单位ID
	 */
	private Long settlementOrgId;
	/**
	 * 结算单位名称
	 */
	private String settlementOrgName;
	/**
	 * 采购类别
	 */
	private Integer agreementVariety;
	/**
	 * 供货周期
	 */
	private Integer supplyCycle;
	/**
	 * 质保期单位
	 */
	private String quaprotectUnit;
	/**
	 * 质保期时间
	 */
	private String quaprotectCount;
	/**
	 * 质保期(月)
	 */
	private Integer warantty;
	/**
	 * 所属专区
	 */
	private Integer agrLocation;
	/**
	 * 是否商城铺货标识
	 */
	private Integer whetherStorePlan;
	/**
	 * 应用范围类型
	 */
	private Integer scopeType;
	/**
	 * 调价机制
	 */
	private Integer adjustPrice;
	/**
	 * 组织名称
	 */
	private String agrOrgName;
	/**
	 * 其他付款条件
	 */
	private String payCase;
	/**
	 * 协议签订时间
	 */
	private Date agrSignTime;
	private Date agrSignTimeStart;
	private Date agrSignTimeEnd;
	/**
	 * 经办人ID
	 */
	private Long agrOperatorId;
	/**
	 * 经办人名称
	 */
	private String agrOperatorName;
	/**
	 * 经办人用户名
	 */
	private String agrOperatorUsername;
	/**
	 * 编制人名称
	 */
	private String createName;
	/**
	 * 编制人用户名
	 */
	private String createUsername;
	/**
	 * 编制人ID
	 */
	private Long createLoginId;
	/**
	 * 编制时间
	 */
	private Date createTime;
	private Date createTimeStart;
	private Date createTimeEnd;
	/**
	 * 编制人单位
	 */
	private Long createOrgId;
	/**
	 * 编制人单位名称
	 */
	private String createOrgName;
	/**
	 * 更新者ID
	 */
	private Long updateLoginId;
	/**
	 * 更新人
	 */
	private String updateName;
	/**
	 * 更新人用户名
	 */
	private String updateUsername;
	/**
	 * 删除标志
	 */
	private Integer delTag;
	/**
	 * 更新时间
	 */
	private Date updateTime;
	private Date updateTimeStart;
	private Date updateTimeEnd;
	/**
	 * 备注
	 */
	private String remark;
	/**
	 * 协议ID集合
	 */
	private List<Long> agrIds;
	/**
	 * 机构树路径
	 */
	private String orgPath;
	/**
	 * 确认时间
	 */
	private Date confirmTime;
	private Date confirmTimeStart;
	private Date confirmTimeEnd;
	/**
	 * 确认人
	 */
	private String confirmName;
	/**
	 * 排序
	 */
	private String orderBy;

}
